==> config-api-1.7.0-sources.jar: org/wildfly/swarm/config/infinispan/cache_container/OffHeapMemory.java <==
package org.wildfly.swarm.config.infinispan.cache_container;

import org.wildfly.swarm.config.runtime.AttributeDocumentation;
import org.wildfly.swarm.config.runtime.ResourceDocumentation;
import org.wildfly.swarm.config.runtime.SingletonResource;
import org.wildfly.swarm.config.runtime.Addresses;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Arrays;
import org.wildfly.swarm.config.infinispan.EvictionType;

/**
 * Off-heap memory configuration.
 */
@Addresses({
		"/subsystem=infinispan/cache-container=*/invalidation-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/local-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/replicated-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/distributed-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/scattered-cache=*/memory=off-heap"})
@ResourceType("memory")
@Implicit
public class OffHeapMemory<T extends OffHeapMemory<T>>
		implements
			org.wildfly.swarm.config.runtime.Keyed {

	private String key;
	private PropertyChangeSupport pcs;
	@AttributeDocumentation("Defines the capacity of the off-heap storage.")
	private Integer capacity;
	@AttributeDocumentation("Indicates whether the size attribute refers to the number of cache entries (i.e. COUNT) or the collective size of the cache entries (i.e. MEMORY).")
	private EvictionType evictionType;
	@AttributeDocumentation("The number of cache eviction operations. May return null if the cache is not started.")
	private Long evictions;
	@AttributeDocumentation("Eviction threshold, as defined by the eviction-type.")
	private Long size;

	public OffHeapMemory() {
		super();
		this.key = "off-heap";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * Defines the capacity of the off-heap storage.
	 */
	@ModelNodeBinding(detypedName = "capacity")
	public Integer capacity() {
		return this.capacity;
	}

	/**
	 * Defines the capacity of the off-heap storage.
	 */
	@SuppressWarnings("unchecked")
	public T capacity(java.lang.Integer value) {
		Object oldValue = this.capacity;
		this.capacity = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("capacity", oldValue, value);
		return (T) this;
	}

	/**
	 * Indicates whether the size attribute refers to the number of cache
	 * entries (i.e. COUNT) or the collective size of the cache entries (i.e.
	 * MEMORY).
	 */
	@ModelNodeBinding(detypedName = "eviction-type")
	public EvictionType evictionType() {
		return this.evictionType;
	}

	/**
	 * Indicates whether the size attribute refers to the number of cache
	 * entries (i.e. COUNT) or the collective size of the cache entries (i.e.
	 * MEMORY).
	 */
	@SuppressWarnings("unchecked")
	public T evictionType(EvictionType value) {
		Object oldValue = this.evictionType;
		this.evictionType = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("evictionType", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of cache eviction operations. May return null if the cache is
	 * not started.
	 */
	@ModelNodeBinding(detypedName = "evictions")
	public Long evictions() {
		return this.evictions;
	}

	/**
	 * The number of cache eviction operations. May return null if the cache is
	 * not started.
	 */
	@SuppressWarnings("unchecked")
	public T evictions(java.lang.Long value) {
		Object oldValue = this.evictions;
		this.evictions = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("evictions", oldValue, value);
		return (T) this;
	}

	/**
	 * Eviction threshold, as defined by the eviction-type.
	 */
	@ModelNodeBinding(detypedName = "size")
	public Long size() {
		return this.size;
	}

	/**
	 * Eviction threshold, as defined by the eviction-type.
	 */
	@SuppressWarnings("unchecked")
	public T size(java.lang.Long value) {
		Object oldValue = this.size;
		this.size = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("size", oldValue, value);
		return (T) this;
	}
}

==> config-api-2.7.0-sources.jar: org/wildfly/swarm/config/infinispan/cache_container/OffHeapMemory.java <==
package org.wildfly.swarm.config.infinispan.cache_container;

import org.wildfly.swarm.config.runtime.AttributeDocumentation;
import org.wildfly.swarm.config.runtime.ResourceDocumentation;
import org.wildfly.swarm.config.runtime.SingletonResource;
import org.wildfly.swarm.config.runtime.Addresses;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Arrays;
import org.wildfly.swarm.config.infinispan.EvictionType;

/**
 * Off-heap memory configuration.
 */
@Addresses({
		"/subsystem=infinispan/cache-container=*/invalidation-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/local-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/replicated-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/distributed-cache=*/memory=off-heap",
		"/subsystem=infinispan/cache-container=*/scattered-cache=*/memory=off-heap"})
@ResourceType("memory")
@Implicit
public class OffHeapMemory<T extends OffHeapMemory<T>>
		implements
			org.wildfly.swarm.config.runtime.Keyed {

	private String key;
	private PropertyChangeSupport pcs;
	@AttributeDocumentation("Defines the capacity of the off-heap storage.")
	private Integer capacity;
	@AttributeDocumentation("Indicates whether the size attribute refers to the number of cache entries (i.e. COUNT) or the collective size of the cache entries (i.e. MEMORY).")
	private EvictionType evictionType;
	@AttributeDocumentation("The number of cache eviction operations.")
	private Long evictions;
	@AttributeDocumentation("Eviction threshold, as defined by the eviction-type.")
	private Long size;

	public OffHeapMemory() {
		super();
		this.key = "off-heap";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * Defines the capacity of the off-heap storage.
	 */
	@ModelNodeBinding(detypedName = "capacity")
	public Integer capacity() {
		return this.capacity;
	}

	/**
	 * Defines the capacity of the off-heap storage.
	 */
	@SuppressWarnings("unchecked")
	public T capacity(java.lang.Integer value) {
		Object oldValue = this.capacity;
		this.capacity = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("capacity", oldValue, value);
		return (T) this;
	}

	/**
	 * Indicates whether the size attribute refers to the number of cache
	 * entries (i.e. COUNT) or the collective size of the cache entries (i.e.
	 * MEMORY).
	 */
	@ModelNodeBinding(detypedName = "eviction-type")
	public EvictionType evictionType() {
		return this.evictionType;
	}

	/**
	 * Indicates whether the size attribute refers to the number of cache
	 * entries (i.e. COUNT) or the collective size of the cache entries (i.e.
	 * MEMORY).
	 */
	@SuppressWarnings("unchecked")
	public T evictionType(EvictionType value) {
		Object oldValue = this.evictionType;
		this.evictionType = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("evictionType", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of cache eviction operations.
	 * 
	 * @deprecated Deprecated. Use corresponding metric on parent resource.
	 */
	@Deprecated
	@ModelNodeBinding(detypedName = "evictions")
	public Long evictions() {
		return this.evictions;
	}

	/**
	 * The number of cache eviction operations.
	 * 
	 * @deprecated Deprecated. Use corresponding metric on parent resource.
	 */
	@SuppressWarnings("unchecked")
	@Deprecated
	public T evictions(java.lang.Long value) {
		Object oldValue = this.evictions;
		this.evictions = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("evictions", oldValue, value);
		return (T) this;
	}

	/**
	 * Eviction threshold, as defined by the eviction-type.
	 */
	@ModelNodeBinding(detypedName = "size")
	public Long size() {
		return this.size;
	}

	/**
	 * Eviction threshold, as defined by the eviction-type.
	 */
	@SuppressWarnings("unchecked")
	public T size(java.lang.Long value) {
		Object oldValue = this.size;
		this.size = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("size", oldValue, value);
		return (T) this;
	}
}
